@@ -6,7 +6,7 @@ Rubric::Renderer - the rendering interface for Rubric
 
 =head1 VERSION
 
- $Id: Renderer.pm,v 1.7 2005/01/26 04:16:21 rjbs Exp $
+ $Id: Renderer.pm,v 1.10 2005/03/31 01:02:53 rjbs Exp $
 
 =head1 DESCRIPTION
 
@@ -19,6 +19,7 @@ use strict;
 use warnings;
 
 use Carp;
+use Rubric;
 use Rubric::Config;
 use Template;
 
@@ -51,6 +52,7 @@ __PACKAGE__->register_type(@$_) for (
 	[ html => { content_type => 'text/html; charset="utf-8"', extension => 'html' } ],
 	[ rss  => { content_type => 'application/rss+xml', extension => 'rss'  } ],
 	[ txt  => { content_type => 'text/plain',          extension => 'txt'  } ],
+	[ api  => { content_type => 'text/xml',            extension => 'api'  } ],
 );
 
 =head2 process($template, $type, \%stash)
@@ -65,7 +67,7 @@ two-element list.  In scalar context, it returns the output document.
 
 =cut
 
-my $xml_quote_escape = sub {
+my $xml_escape = sub {
 	for (shift) {
 		s/&/&amp;/g;
 		s/</&lt;/g;
@@ -80,7 +82,8 @@ sub process {
 	my ($class, $template, $type, $stash) = @_;
 	return unless $renderer{$type};
 
-	$stash->{quote_escape} = $xml_quote_escape;
+	$stash->{xml_escape} = $xml_escape;
+	$stash->{version} = $Rubric::VERSION;
 
 	$template .= '.' . $renderer{$type}{extension};
 	$renderer{$type}{renderer}->process($template, $stash, \(my $output))
