@@ -6,13 +6,13 @@ Rubric::WebApp - the web interface to Rubric
 
 =head1 VERSION
 
-version 0.06
+version 0.08
 
- $Id: WebApp.pm,v 1.81 2005/01/26 04:18:58 rjbs Exp $
+ $Id: WebApp.pm,v 1.99 2005/04/07 22:44:42 rjbs Exp $
 
 =cut
 
-our $VERSION = '0.06';
+our $VERSION = '0.08';
 
 =head1 SYNOPSIS
 
@@ -46,9 +46,9 @@ basic dispatch table looks something like this:
  /post        | post or edit an entry (must be logged in) | post
  /edit        | edit an entry (must be logged in)         | edit
  /delete      | delete an entry (must be logged in)       | delete
- /user/NAME   | see a user's entries                      | user
- /user/N/TAGS | see a user's entries for given tags       | user
- /tag/TAGS    | see entries for given tags                | tag
+ /entry/ENTRY | find and display the identified entry     | entry
+ /entries/Q   | find and display results for query Q      | entries
+ /~USER/TAGS  | see a user's entries for given tags       | (in flux)
  /doc/PAGE    | view the named page in the documentation  | doc
 
 If the system is private and no user is logged in, the default action is to
@@ -151,11 +151,13 @@ sub check_pager_data {
 	my ($self) = @_;
 
 	$self->session->param('per_page', int(
-		$self->query->param('per_page') || $self->session->param('per_page') || 25
+		$self->query->param('per_page')
+		|| $self->session->param('per_page')
+		|| Rubric::Config->default_page_size
 	));
  
-	$self->session->param('per_page', 100)
- 		if $self->session->param('per_page') > 100;
+	$self->session->param('per_page', Rubric::Config->max_page_size)
+ 		if $self->session->param('per_page') > Rubric::Config->max_page_size;
 
 	$self->param('per_page', $self->session->param('per_page'));
 	$self->param('page',     int(($self->query->param('page') || 1)));
@@ -216,7 +218,22 @@ sub setup {
 		]);
 	}
 
-	$self->run_modes(AUTOLOAD => 'redirect_root');
+	$self->run_modes(AUTOLOAD => '_default_handler');
+}
+
+sub _default_handler {
+	my ($self, $runmode) = @_;
+	if (substr($runmode, 0, 1) eq '~') {
+		return $self->_entries_shortcut(substr($runmode, 1));
+	}
+	$self->redirect_root;
+}
+
+sub _entries_shortcut {
+	my ($self, $user) = @_;
+	my $path = $self->param('path');
+	unshift @$path, 'user', $user, 'tags';
+	$self->entries;
 }
 
 =head2 entries
@@ -243,8 +260,8 @@ This displays the single requested entry.
 sub entry {
 	my ($self) = @_;
 
-	return $self->redirect_root("No such entry...")
-		unless ($self->get_entry);
+	return $self->template('no_entry', { reason => 'missing' })
+		unless $self->get_entry->param('entry');
 
 	$self->template('entry_long' => {
 		entry => $self->param('entry'),
@@ -262,7 +279,8 @@ id, and puts the corresponding entry in the "entry" parameter.
 sub get_entry {
 	my ($self) = @_;
 
-	$self->param(entry => Rubric::Entry->retrieve($self->next_path_part));
+	my $entry = Rubric::Entry->retrieve($self->next_path_part);
+	$self->param(entry => $entry);
 	return $self;
 }
 
@@ -356,8 +374,7 @@ settings may be changed.
 sub preferences {
 	my ($self) = @_;
 
-	return $self->redirect_root("permission denied")
-		unless $self->param('current_user');
+	return $self->login unless $self->param('current_user');	
 	
 	return $self->template("preferences")
 		unless my %prefs = $self->_get_prefs_form;
@@ -589,11 +606,6 @@ sub get_verification_code {
 	return $self;
 }
 
-# sub user {
-#	my ($self) = @_;
-#	$self->get_user->get_tags->display_entries;
-#}
-
 =head2 get_user
 
 This gets the next part of the path and puts it in the C<user> parameter.
@@ -683,6 +695,7 @@ sub render_entries {
 		pages   => $self->param('pages'),
 		%$options,
 		remove       => sub { [ grep { $_ ne $_[0] } @{$_[1]} ] },
+		self_url     => $self->query->self_url(),
 		long_form    => scalar $self->query->param('long_form'),
 		recent_tags  => $self->param('recent_tags'),
 	});
@@ -698,9 +711,11 @@ displays a post form, completed with the given entry's data.
 sub edit {
 	my ($self) = @_;
 
-	return $self->redirect_root("...huh?")
-		unless $self->get_entry
-		and $self->param('entry')->user eq $self->param('current_user');
+	return $self->template('no_entry', { reason => 'missing' })
+		unless $self->get_entry->param('entry');
+	
+	return $self->template('no_entry', { reason => 'access' })
+		unless $self->param('entry')->user eq $self->param('current_user');
 
 	$self->param('existing_entry', $self->param('entry'));
 	return $self->post_form();
@@ -719,37 +734,69 @@ If a new entry is created, the user is redirected to his entry listing.
 
 =cut
 
-sub post {
+sub _post_form_contents {
 	my ($self) = @_;
+	my (%form, %error);
 
-	return $self->login unless my $user = $self->param('current_user');	
-
-	my %entry;
-	$entry{$_} = $self->query->param($_)
+	$form{$_} = $self->query->param($_)
 		for qw(entryid uri title description tags body);
-	eval { $entry{uri} = URI->new($entry{uri})->canonical->as_string; };
+	eval { $form{uri} = URI->new($form{uri})->canonical; };
+	$error{uri} = "Invalid URI" if $@;
+	if (
+		$form{uri}
+		and not $error{uri}
+		and defined Rubric::Config->allowed_schemes
+		and not grep { $_ eq $form{uri}->scheme } @{ Rubric::Config->allowed_schemes }
+	) {
+		$error{uri} = "Invalid URI; valid schemes are: "
+			. join(" ", @{ Rubric::Config->allowed_schemes });
+	}
+	$error{tags} =
+		"Tags may only contain letters, numbers, dot, colon, and asterisk."
+		if $form{tags} =~ /[^\s\w\d:.*]/;
 
-	if ($entry{uri}) {
-		if (my ($link) = Rubric::Link->search({uri => $entry{uri}})) {
-			if (my ($existing_entry) = Rubric::Entry->search({link => $link, user => $user})) {
+	if ($form{uri} and Rubric::Config->one_entry_per_link) {
+		if (my ($link) = Rubric::Link->search({uri => $form{uri}})) {
+			my $existing_entry = Rubric::Entry->search(
+				{link => $link, user => $self->param('current_user') }
+			);
+			if ($existing_entry) {
 				$self->param('existing_entry', $existing_entry);
 			}
 		}
 	}
 	
-	return $self->post_form(\%entry) unless
-		(($self->query->param('submit') || '') eq 'save')
-		and	
-		$self->param('current_user')->quick_entry(\%entry);
+	return (\%form, \%error);
+}
+
+sub post {
+	my ($self) = @_;
+
+	return $self->login unless my $user = $self->param('current_user');	
+
+	my ($form, $error) = $self->_post_form_contents;
+
+	return $self->post_form($form, $error) if
+		(($self->query->param('submit') || '') ne 'save')
+		or %$error
+		or not $self->param('current_user')->quick_entry($form);
 	
 	my $when_done = $self->query->param('when_done');
 
 	return $self->template('close_window') if $when_done eq 'close';
 
-	my $goto_uri = ($when_done eq 'go_back')
-		? $entry{uri}
-		: Rubric::WebApp::URI->entries({ user => $self->param('current_user') });
-	
+	my $then_goto = $self->query->param('then_goto');
+
+	my $goto_uri;
+
+	if ($then_goto) {
+		$goto_uri = $then_goto;
+	} elsif ($when_done eq 'go_back' && $form->{uri}) {
+		$goto_uri = $form->{uri};
+	} else {
+		$goto_uri = Rubric::WebApp::URI->entries({ user => $self->param('current_user') });
+	}
+
 	return $self->redirect( $goto_uri, "Posted..." );
 }
 
@@ -760,13 +807,15 @@ This method renders a form for the user to create a new entry.
 =cut
 
 sub post_form {
-	my ($self, $entry) = @_;
+	my ($self, $form, $error) = @_;
 
 	$self->template( 'post' => {
-		form           => $entry,
+		form           => $form,
+		error          => $error,
 		user           => scalar $self->param('current_user'),
 		existing_entry => scalar $self->param('existing_entry'),
-		when_done      => scalar $self->query->param('when_done')
+		then_goto      => scalar $self->query->param('then_goto'),
+		when_done      => scalar $self->query->param('when_done'),
 	});
 }
 
